summaryrefslogtreecommitdiffstats
path: root/scripts/qt
diff options
context:
space:
mode:
authorSergio Ahumada <sahumada@blackberry.com>2014-02-24 15:24:11 +0100
committerThe Qt Project <gerrit-noreply@qt-project.org>2014-03-03 09:29:57 +0100
commita40f91f7289b160e35f04f0655bcc876d63356c2 (patch)
tree4503841cf3e532bdbc4bfccd56d6d635464b717f /scripts/qt
parent5f4a961316deaaad666a0a8616f86e02fcfc0166 (diff)
qtmod_test: Fix run_install_check() when cross compilating
run_install_check() assumes that we are doing a Desktop build so it expects the /include/ directory to end up under $(qt.install.dir)/include which is not always true, especially when you are cross compiling and using -sysroot and/or -headerdir which may place the /include/ directory somewhere else. Let's check for 'bin' and 'mkspecs' instead, as it's more likely they end up under $(qt.install.dir) as they are host related artifacts. Change-Id: I29463fa73916d08880bb5f15fa1b6ca721511c43 Reviewed-by: Frederik Gladhorn <frederik.gladhorn@digia.com> Reviewed-by: Tony Sarajärvi <tony.sarajarvi@digia.com> Reviewed-by: Simo Fält <simo.falt@digia.com>
Diffstat (limited to 'scripts/qt')
-rwxr-xr-xscripts/qt/qtmod_test.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/qt/qtmod_test.pl b/scripts/qt/qtmod_test.pl
index cc25f7b7..17e0a6c4 100755
--- a/scripts/qt/qtmod_test.pl
+++ b/scripts/qt/qtmod_test.pl
@@ -1114,8 +1114,8 @@ sub run_install_check
return if (!$qt_make_install);
- # check whether dirs 'bin' and 'include' actually exists under qt.install.dir
- my @required_files = map { "$qt_install_dir/$_" } qw(bin include);
+ # check whether dirs 'bin' and 'mkspecs' actually exists under qt.install.dir
+ my @required_files = map { "$qt_install_dir/$_" } qw(bin mkspecs);
my @missing_files = grep { ! -e $_ } @required_files;
if (@missing_files) {
$self->fail(